==> openshift-model-monitoring-5.11.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/PushoverConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.SecretKeySelector;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class PushoverConfigFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1alpha1.PushoverConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1alpha1.PushoverConfigFluent<A>{
  public PushoverConfigFluentImpl() {
  }
  public PushoverConfigFluentImpl(io.fabric8.openshift.api.model.monitoring.v1alpha1.PushoverConfig instance) {
    this.withExpire(instance.getExpire()); 
    this.withHtml(instance.getHtml()); 
    this.withHttpConfig(instance.getHttpConfig()); 
    this.withMessage(instance.getMessage()); 
    this.withPriority(instance.getPriority()); 
    this.withRetry(instance.getRetry()); 
    this.withSendResolved(instance.getSendResolved()); 
    this.withSound(instance.getSound()); 
    this.withTitle(instance.getTitle()); 
    this.withToken(instance.getToken()); 
    this.withUrl(instance.getUrl()); 
    this.withUrlTitle(instance.getUrlTitle()); 
    this.withUserKey(instance.getUserKey()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String expire;
  private java.lang.Boolean html;
  private io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder httpConfig;
  private java.lang.String message;
  private java.lang.String priority;
  private java.lang.String retry;
  private java.lang.Boolean sendResolved;
  private java.lang.String sound;
  private java.lang.String title;
  private io.fabric8.kubernetes.api.model.SecretKeySelector token;
  private java.lang.String url;
  private java.lang.String urlTitle;
  private io.fabric8.kubernetes.api.model.SecretKeySelector userKey;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getExpire() {
    return this.expire;
  }
  public A withExpire(java.lang.String expire) {
    this.expire=expire; return (A) this;
  }
  public java.lang.Boolean hasExpire() {
    return this.expire != null;
  }
  
  /**
   * Method is deprecated. use withExpire instead.
   */
  @java.lang.Deprecated
  public A withNewExpire(java.lang.String arg0) {
    return (A)withExpire(new String(arg0));
  }
  public java.lang.Boolean getHtml() {
    return this.html;
  }
  public A withHtml(java.lang.Boolean html) {
    this.html=html; return (A) this;
  }
  public java.lang.Boolean hasHtml() {
    return this.html != null;
  }
  
  /**
   * This method has been deprecated, please use method buildHttpConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig getHttpConfig() {
    return this.httpConfig!=null?this.httpConfig.build():null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig buildHttpConfig() {
    return this.httpConfig!=null?this.httpConfig.build():null;
  }
  public A withHttpConfig(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig httpConfig) {
    _visitables.get("httpConfig").remove(this.httpConfig);
    if (httpConfig!=null){ this.httpConfig= new io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder(httpConfig); _visitables.get("httpConfig").add(this.httpConfig);} return (A) this;
  }
  public java.lang.Boolean hasHttpConfig() {
    return this.httpConfig != null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.PushoverConfigFluent.HttpConfigNested<A> withNewHttpConfig() {
    return new io.fabric8.openshift.api.model.monitoring.v1alpha1.PushoverConfigFluentImpl.HttpConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.PushoverConfigFluent.HttpConfigNested<A> withNewHttpConfigLike(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig item) {
    return new io.fabric8.openshift.api.model.monitoring.v1alpha1.PushoverConfigFluentImpl.HttpConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.PushoverConfigFluent.HttpConfigNested<A> editHttpConfig() {
    return withNewHttpConfigLike(getHttpConfig());
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.PushoverConfigFluent.HttpConfigNested<A> editOrNewHttpConfig() {
    return withNewHttpConfigLike(getHttpConfig() != null ? getHttpConfig(): new io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.PushoverConfigFluent.HttpConfigNested<A> editOrNewHttpConfigLike(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig item) {
    return withNewHttpConfigLike(getHttpConfig() != null ? getHttpConfig(): item);
  }
  public java.lang.String getMessage() {
    return this.message;
  }
  public A withMessage(java.lang.String message) {
    this.message=message; return (A) this;
  }
  public java.lang.Boolean hasMessage() {
    return this.message != null;
  }
  
  /**
   * Method is deprecated. use withMessage instead.
   */
  @java.lang.Deprecated
  public A withNewMessage(java.lang.String arg0) {
    return (A)withMessage(new String(arg0));
  }
  public java.lang.String getPriority() {
    return this.priority;
  }
  public A withPriority(java.lang.String priority) {
    this.priority=priority; return (A) this;
  }
  public java.lang.Boolean hasPriority() {
    return this.priority != null;
  }
  
  /**
   * Method is deprecated. use withPriority instead.
   */
  @java.lang.Deprecated
  public A withNewPriority(java.lang.String arg0) {
    return (A)withPriority(new String(arg0));
  }
  public java.lang.String getRetry() {
    return this.retry;
  }
  public A withRetry(java.lang.String retry) {
    this.retry=retry; return (A) this;
  }
  public java.lang.Boolean hasRetry() {
    return this.retry != null;
  }
  
  /**
   * Method is deprecated. use withRetry instead.
   */
  @java.lang.Deprecated
  public A withNewRetry(java.lang.String arg0) {
    return (A)withRetry(new String(arg0));
  }
  public java.lang.Boolean getSendResolved() {
    return this.sendResolved;
  }
  public A withSendResolved(java.lang.Boolean sendResolved) {
    this.sendResolved=sendResolved; return (A) this;
  }
  public java.lang.Boolean hasSendResolved() {
    return this.sendResolved != null;
  }
  public java.lang.String getSound() {
    return this.sound;
  }
  public A withSound(java.lang.String sound) {
    this.sound=sound; return (A) this;
  }
  public java.lang.Boolean hasSound() {
    return this.sound != null;
  }
  
  /**
   * Method is deprecated. use withSound instead.
   */
  @java.lang.Deprecated
  public A withNewSound(java.lang.String arg0) {
    return (A)withSound(new String(arg0));
  }
  public java.lang.String getTitle() {
    return this.title;
  }
  public A withTitle(java.lang.String title) {
    this.title=title; return (A) this;
  }
  public java.lang.Boolean hasTitle() {
    return this.title != null;
  }
  
  /**
   * Method is deprecated. use withTitle instead.
   */
  @java.lang.Deprecated
  public A withNewTitle(java.lang.String arg0) {
    return (A)withTitle(new String(arg0));
  }
  public io.fabric8.kubernetes.api.model.SecretKeySelector getToken() {
    return this.token;
  }
  public A withToken(io.fabric8.kubernetes.api.model.SecretKeySelector token) {
    this.token=token; return (A) this;
  }
  public java.lang.Boolean hasToken() {
    return this.token != null;
  }
  public A withNewToken(java.lang.String key,java.lang.String name,java.lang.Boolean optional) {
    return (A)withToken(new SecretKeySelector(key, name, optional));
  }
  public java.lang.String getUrl() {
    return this.url;
  }
  public A withUrl(java.lang.String url) {
    this.url=url; return (A) this;
  }
  public java.lang.Boolean hasUrl() {
    return this.url != null;
  }
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0) {
    return (A)withUrl(new String(arg0));
  }
  public java.lang.String getUrlTitle() {
    return this.urlTitle;
  }
  public A withUrlTitle(java.lang.String urlTitle) {
    this.urlTitle=urlTitle; return (A) this;
  }
  public java.lang.Boolean hasUrlTitle() {
    return this.urlTitle != null;
  }
  
  /**
   * Method is deprecated. use withUrlTitle instead.
   */
  @java.lang.Deprecated
  public A withNewUrlTitle(java.lang.String arg0) {
    return (A)withUrlTitle(new String(arg0));
  }
  public io.fabric8.kubernetes.api.model.SecretKeySelector getUserKey() {
    return this.userKey;
  }
  public A withUserKey(io.fabric8.kubernetes.api.model.SecretKeySelector userKey) {
    this.userKey=userKey; return (A) this;
  }
  public java.lang.Boolean hasUserKey() {
    return this.userKey != null;
  }
  public A withNewUserKey(java.lang.String key,java.lang.String name,java.lang.Boolean optional) {
    return (A)withUserKey(new SecretKeySelector(key, name, optional));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PushoverConfigFluentImpl that = (PushoverConfigFluentImpl) o;
    if (expire != null ? !expire.equals(that.expire) :that.expire != null) return false;
    if (html != null ? !html.equals(that.html) :that.html != null) return false;
    if (httpConfig != null ? !httpConfig.equals(that.httpConfig) :that.httpConfig != null) return false;
    if (message != null ? !message.equals(that.message) :that.message != null) return false;
    if (priority != null ? !priority.equals(that.priority) :that.priority != null) return false;
    if (retry != null ? !retry.equals(that.retry) :that.retry != null) return false;
    if (sendResolved != null ? !sendResolved.equals(that.sendResolved) :that.sendResolved != null) return false;
    if (sound != null ? !sound.equals(that.sound) :that.sound != null) return false;
    if (title != null ? !title.equals(that.title) :that.title != null) return false;
    if (token != null ? !token.equals(that.token) :that.token != null) return false;
    if (url != null ? !url.equals(that.url) :that.url != null) return false;
    if (urlTitle != null ? !urlTitle.equals(that.urlTitle) :that.urlTitle != null) return false;
    if (userKey != null ? !userKey.equals(that.userKey) :that.userKey != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(expire,  html,  httpConfig,  message,  priority,  retry,  sendResolved,  sound,  title,  token,  url,  urlTitle,  userKey,  additionalProperties,  super.hashCode());
  }
  public class HttpConfigNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1alpha1.PushoverConfigFluent.HttpConfigNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1alpha1.PushoverConfigFluent.HttpConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    HttpConfigNestedImpl(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig item) {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder(this, item);
    }
    HttpConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder builder;
    public N and() {
      return (N) PushoverConfigFluentImpl.this.withHttpConfig(builder.build());
    }
    public N endHttpConfig() {
      return and();
    }
    
  }
  
}

==> openshift-model-monitoring-5.12.2-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/PushoverConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.SecretKeySelector;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class PushoverConfigFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1alpha1.PushoverConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1alpha1.PushoverConfigFluent<A>{
  public PushoverConfigFluentImpl() {
  }
  public PushoverConfigFluentImpl(io.fabric8.openshift.api.model.monitoring.v1alpha1.PushoverConfig instance) {
    this.withExpire(instance.getExpire()); 
    this.withHtml(instance.getHtml()); 
    this.withHttpConfig(instance.getHttpConfig()); 
    this.withMessage(instance.getMessage()); 
    this.withPriority(instance.getPriority()); 
    this.withRetry(instance.getRetry()); 
    this.withSendResolved(instance.getSendResolved()); 
    this.withSound(instance.getSound()); 
    this.withTitle(instance.getTitle()); 
    this.withToken(instance.getToken()); 
    this.withUrl(instance.getUrl()); 
    this.withUrlTitle(instance.getUrlTitle()); 
    this.withUserKey(instance.getUserKey()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String expire;
  private java.lang.Boolean html;
  private io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder httpConfig;
  private java.lang.String message;
  private java.lang.String priority;
  private java.lang.String retry;
  private java.lang.Boolean sendResolved;
  private java.lang.String sound;
  private java.lang.String title;
  private io.fabric8.kubernetes.api.model.SecretKeySelector token;
  private java.lang.String url;
  private java.lang.String urlTitle;
  private io.fabric8.kubernetes.api.model.SecretKeySelector userKey;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getExpire() {
    return this.expire;
  }
  public A withExpire(java.lang.String expire) {
    this.expire=expire; return (A) this;
  }
  public java.lang.Boolean hasExpire() {
    return this.expire != null;
  }
  
  /**
   * Method is deprecated. use withExpire instead.
   */
  @java.lang.Deprecated
  public A withNewExpire(java.lang.String arg0) {
    return (A)withExpire(new String(arg0));
  }
  public java.lang.Boolean getHtml() {
    return this.html;
  }
  public A withHtml(java.lang.Boolean html) {
    this.html=html; return (A) this;
  }
  public java.lang.Boolean hasHtml() {
    return this.html != null;
  }
  
  /**
   * This method has been deprecated, please use method buildHttpConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig getHttpConfig() {
    return this.httpConfig!=null?this.httpConfig.build():null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig buildHttpConfig() {
    return this.httpConfig!=null?this.httpConfig.build():null;
  }
  public A withHttpConfig(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig httpConfig) {
    _visitables.get("httpConfig").remove(this.httpConfig);
    if (httpConfig!=null){ this.httpConfig= new io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder(httpConfig); _visitables.get("httpConfig").add(this.httpConfig);} return (A) this;
  }
  public java.lang.Boolean hasHttpConfig() {
    return this.httpConfig != null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.PushoverConfigFluent.HttpConfigNested<A> withNewHttpConfig() {
    return new io.fabric8.openshift.api.model.monitoring.v1alpha1.PushoverConfigFluentImpl.HttpConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.PushoverConfigFluent.HttpConfigNested<A> withNewHttpConfigLike(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig item) {
    return new io.fabric8.openshift.api.model.monitoring.v1alpha1.PushoverConfigFluentImpl.HttpConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.PushoverConfigFluent.HttpConfigNested<A> editHttpConfig() {
    return withNewHttpConfigLike(getHttpConfig());
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.PushoverConfigFluent.HttpConfigNested<A> editOrNewHttpConfig() {
    return withNewHttpConfigLike(getHttpConfig() != null ? getHttpConfig(): new io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.PushoverConfigFluent.HttpConfigNested<A> editOrNewHttpConfigLike(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig item) {
    return withNewHttpConfigLike(getHttpConfig() != null ? getHttpConfig(): item);
  }
  public java.lang.String getMessage() {
    return this.message;
  }
  public A withMessage(java.lang.String message) {
    this.message=message; return (A) this;
  }
  public java.lang.Boolean hasMessage() {
    return this.message != null;
  }
  
  /**
   * Method is deprecated. use withMessage instead.
   */
  @java.lang.Deprecated
  public A withNewMessage(java.lang.String arg0) {
    return (A)withMessage(new String(arg0));
  }
  public java.lang.String getPriority() {
    return this.priority;
  }
  public A withPriority(java.lang.String priority) {
    this.priority=priority; return (A) this;
  }
  public java.lang.Boolean hasPriority() {
    return this.priority != null;
  }
  
  /**
   * Method is deprecated. use withPriority instead.
   */
  @java.lang.Deprecated
  public A withNewPriority(java.lang.String arg0) {
    return (A)withPriority(new String(arg0));
  }
  public java.lang.String getRetry() {
    return this.retry;
  }
  public A withRetry(java.lang.String retry) {
    this.retry=retry; return (A) this;
  }
  public java.lang.Boolean hasRetry() {
    return this.retry != null;
  }
  
  /**
   * Method is deprecated. use withRetry instead.
   */
  @java.lang.Deprecated
  public A withNewRetry(java.lang.String arg0) {
    return (A)withRetry(new String(arg0));
  }
  public java.lang.Boolean getSendResolved() {
    return this.sendResolved;
  }
  public A withSendResolved(java.lang.Boolean sendResolved) {
    this.sendResolved=sendResolved; return (A) this;
  }
  public java.lang.Boolean hasSendResolved() {
    return this.sendResolved != null;
  }
  public java.lang.String getSound() {
    return this.sound;
  }
  public A withSound(java.lang.String sound) {
    this.sound=sound; return (A) this;
  }
  public java.lang.Boolean hasSound() {
    return this.sound != null;
  }
  
  /**
   * Method is deprecated. use withSound instead.
   */
  @java.lang.Deprecated
  public A withNewSound(java.lang.String arg0) {
    return (A)withSound(new String(arg0));
  }
  public java.lang.String getTitle() {
    return this.title;
  }
  public A withTitle(java.lang.String title) {
    this.title=title; return (A) this;
  }
  public java.lang.Boolean hasTitle() {
    return this.title != null;
  }
  
  /**
   * Method is deprecated. use withTitle instead.
   */
  @java.lang.Deprecated
  public A withNewTitle(java.lang.String arg0) {
    return (A)withTitle(new String(arg0));
  }
  public io.fabric8.kubernetes.api.model.SecretKeySelector getToken() {
    return this.token;
  }
  public A withToken(io.fabric8.kubernetes.api.model.SecretKeySelector token) {
    this.token=token; return (A) this;
  }
  public java.lang.Boolean hasToken() {
    return this.token != null;
  }
  public A withNewToken(java.lang.String key,java.lang.String name,java.lang.Boolean optional) {
    return (A)withToken(new SecretKeySelector(key, name, optional));
  }
  public java.lang.String getUrl() {
    return this.url;
  }
  public A withUrl(java.lang.String url) {
    this.url=url; return (A) this;
  }
  public java.lang.Boolean hasUrl() {
    return this.url != null;
  }
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0) {
    return (A)withUrl(new String(arg0));
  }
  public java.lang.String getUrlTitle() {
    return this.urlTitle;
  }
  public A withUrlTitle(java.lang.String urlTitle) {
    this.urlTitle=urlTitle; return (A) this;
  }
  public java.lang.Boolean hasUrlTitle() {
    return this.urlTitle != null;
  }
  
  /**
   * Method is deprecated. use withUrlTitle instead.
   */
  @java.lang.Deprecated
  public A withNewUrlTitle(java.lang.String arg0) {
    return (A)withUrlTitle(new String(arg0));
  }
  public io.fabric8.kubernetes.api.model.SecretKeySelector getUserKey() {
    return this.userKey;
  }
  public A withUserKey(io.fabric8.kubernetes.api.model.SecretKeySelector userKey) {
    this.userKey=userKey; return (A) this;
  }
  public java.lang.Boolean hasUserKey() {
    return this.userKey != null;
  }
  public A withNewUserKey(java.lang.String key,java.lang.String name,java.lang.Boolean optional) {
    return (A)withUserKey(new SecretKeySelector(key, name, optional));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PushoverConfigFluentImpl that = (PushoverConfigFluentImpl) o;
    if (expire != null ? !expire.equals(that.expire) :that.expire != null) return false;
    if (html != null ? !html.equals(that.html) :that.html != null) return false;
    if (httpConfig != null ? !httpConfig.equals(that.httpConfig) :that.httpConfig != null) return false;
    if (message != null ? !message.equals(that.message) :that.message != null) return false;
    if (priority != null ? !priority.equals(that.priority) :that.priority != null) return false;
    if (retry != null ? !retry.equals(that.retry) :that.retry != null) return false;
    if (sendResolved != null ? !sendResolved.equals(that.sendResolved) :that.sendResolved != null) return false;
    if (sound != null ? !sound.equals(that.sound) :that.sound != null) return false;
    if (title != null ? !title.equals(that.title) :that.title != null) return false;
    if (token != null ? !token.equals(that.token) :that.token != null) return false;
    if (url != null ? !url.equals(that.url) :that.url != null) return false;
    if (urlTitle != null ? !urlTitle.equals(that.urlTitle) :that.urlTitle != null) return false;
    if (userKey != null ? !userKey.equals(that.userKey) :that.userKey != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(expire,  html,  httpConfig,  message,  priority,  retry,  sendResolved,  sound,  title,  token,  url,  urlTitle,  userKey,  additionalProperties,  super.hashCode());
  }
  public class HttpConfigNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1alpha1.PushoverConfigFluent.HttpConfigNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1alpha1.PushoverConfigFluent.HttpConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    HttpConfigNestedImpl(io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfig item) {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder(this, item);
    }
    HttpConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1alpha1.HTTPConfigBuilder builder;
    public N and() {
      return (N) PushoverConfigFluentImpl.this.withHttpConfig(builder.build());
    }
    public N endHttpConfig() {
      return and();
    }
    
  }
  
}
